@@ -149,3 +149,17 @@ class Boolean(CopyInterface):
             Current boolean value.
         """
         return self._value
+
+    def __repr__(self) -> str:
+        """
+        Get a representation string of this instance.
+
+        Returns
+        -------
+        repr_str : str
+            Representation string of this instance.
+        """
+        repr_str: str = (
+            f'Boolean({self._value})'
+        )
+        return repr_str
